Exception: AxeCuprite::InjectionError
- Defined in:
- lib/axe/cuprite/errors.rb
Overview
Raised when axe could not be injected into the page (e.g. a strict Content-Security-Policy blocked both inline injection and add_script_tag).
Raised when axe could not be injected into the page (e.g. a strict Content-Security-Policy blocked both inline injection and add_script_tag).